@@ -77,10 +77,13 @@ let convert_concl_no_check a =
 
 let parse_entry e s = Pcoq.Entry.parse e (Pcoq.Parsable.make s)
 
-let find_reference t1 t2 x =
-  lazy (of_constr (constr_of_global (gen_reference_in_modules t1 [t2] x)))
-
-let coq_reference t1 t2 x = find_reference t1 ("Coq" :: t2) x
+let find_reference dir =
+  let dp = DirPath.make (List.rev_map Id.of_string dir) in
+  fun s -> lazy (
+  let sp = Libnames.make_path dp (Id.of_string s) in
+  let qid = Libnames.qualid_of_path sp in
+  let r = Smartlocate.global_with_alias qid in
+  of_constr (constr_of_global r))
 
 let is_global c t = eq_constr (Lazy.force c) t
 
@@ -141,7 +144,7 @@ type pred =
 
 (** {1 Symbols needed by the tactics} *)
 
-let coq_Logic = coq_reference "Gappa" ["Init"; "Logic"]
+let coq_Logic = find_reference ["Coq"; "Init"; "Logic"]
 let coq_False = coq_Logic "False"
 let coq_True = coq_Logic "True"
 let coq_eq = coq_Logic "eq"
@@ -150,14 +153,14 @@ let coq_not = coq_Logic "not"
 let coq_and = coq_Logic "and"
 let coq_or = coq_Logic "or"
 
-let coq_ref_Datatypes = coq_reference "Gappa" ["Init"; "Datatypes"]
+let coq_ref_Datatypes = find_reference ["Coq"; "Init"; "Datatypes"]
 let coq_Some = coq_ref_Datatypes "Some"
 let coq_cons = coq_ref_Datatypes "cons"
 let coq_nil = coq_ref_Datatypes "nil"
 let coq_bool = coq_ref_Datatypes "bool"
 let coq_true = coq_ref_Datatypes "true"
 
-let coq_ref_BinNums = coq_reference "Gappa" ["Numbers"; "BinNums"]
+let coq_ref_BinNums = find_reference ["Coq"; "Numbers"; "BinNums"]
 let coq_Z0 = coq_ref_BinNums "Z0"
 let coq_Zpos = coq_ref_BinNums "Zpos"
 let coq_Zneg = coq_ref_BinNums "Zneg"
@@ -165,7 +168,7 @@ let coq_xH = coq_ref_BinNums "xH"
 let coq_xI = coq_ref_BinNums "xI"
 let coq_xO = coq_ref_BinNums "xO"
 
-let coq_ref_Rdefinitions = coq_reference "Gappa" ["Reals"; "Rdefinitions"]
+let coq_ref_Rdefinitions = find_reference ["Coq"; "Reals"; "Rdefinitions"]
 let coq_R = coq_ref_Rdefinitions "R"
 let coq_R0 = coq_ref_Rdefinitions "R0"
 let coq_R1 = coq_ref_Rdefinitions "R1"
@@ -177,13 +180,13 @@ let coq_Rmult = coq_ref_Rdefinitions "Rmult"
 let coq_Rinv = coq_ref_Rdefinitions "Rinv"
 let coq_Rdiv = coq_ref_Rdefinitions "Rdiv"
 let coq_IZR = coq_ref_Rdefinitions "IZR"
-let coq_Rabs = coq_reference "Gappa" ["Reals"; "Rbasic_fun"] "Rabs"
-let coq_sqrt = coq_reference "Gappa" ["Reals"; "R_sqrt"] "sqrt"
-let coq_powerRZ = coq_reference "Gappa" ["Reals"; "Rfunctions"] "powerRZ"
+let coq_Rabs = find_reference ["Coq"; "Reals"; "Rbasic_fun"] "Rabs"
+let coq_sqrt = find_reference ["Coq"; "Reals"; "R_sqrt"] "sqrt"
+let coq_powerRZ = find_reference ["Coq"; "Reals"; "Rfunctions"] "powerRZ"
 
-let coq_radix_val = find_reference "Gappa" ["Flocq"; "Core"; "Zaux"] "radix_val"
+let coq_radix_val = find_reference ["Flocq"; "Core"; "Zaux"] "radix_val"
 
-let coq_ref_Gappa_Private = find_reference "Gappa" ["Gappa"; "Gappa_tactic"; "Gappa_Private"]
+let coq_ref_Gappa_Private = find_reference ["Gappa"; "Gappa_tactic"; "Gappa_Private"]
 let coq_convert_tree = coq_ref_Gappa_Private "convert_tree"
 let coq_RTree = coq_ref_Gappa_Private "RTree"
 let coq_rtTrue = coq_ref_Gappa_Private "rtTrue"
@@ -230,24 +233,24 @@ let coq_uoNeg = coq_ref_Gappa_Private "uoNeg"
 let coq_uoInv = coq_ref_Gappa_Private "uoInv"
 let coq_uoSqrt = coq_ref_Gappa_Private "uoSqrt"
 
-let coq_ref_Fcore_Raux = find_reference "Gappa" ["Flocq"; "Core"; "Raux"]
+let coq_ref_Fcore_Raux = find_reference ["Flocq"; "Core"; "Raux"]
 let coq_bpow = coq_ref_Fcore_Raux "bpow"
 let coq_rndDN = coq_ref_Fcore_Raux "Zfloor"
 let coq_rndUP = coq_ref_Fcore_Raux "Zceil"
 let coq_rndZR = coq_ref_Fcore_Raux "Ztrunc"
-let coq_ref_Gappa_round_def = find_reference "Gappa" ["Gappa"; "Gappa_round_def"]
+let coq_ref_Gappa_round_def = find_reference ["Gappa"; "Gappa_round_def"]
 let coq_rndNE = coq_ref_Gappa_round_def "rndNE"
 let coq_rndNA = coq_ref_Gappa_round_def "rndNA"
-let coq_ref_Fcore_generic_fmt = find_reference "Gappa" ["Flocq"; "Core"; "Generic_fmt"]
+let coq_ref_Fcore_generic_fmt = find_reference ["Flocq"; "Core"; "Generic_fmt"]
 let coq_round = coq_ref_Fcore_generic_fmt "round"
 let coq_generic_format = coq_ref_Fcore_generic_fmt "generic_format"
-let coq_ref_Fcore_FLT = find_reference "Gappa" ["Flocq"; "Core"; "FLT"]
+let coq_ref_Fcore_FLT = find_reference ["Flocq"; "Core"; "FLT"]
 let coq_FLT_format = coq_ref_Fcore_FLT "FLT_format"
 let coq_FLT_exp = coq_ref_Fcore_FLT "FLT_exp"
-let coq_ref_Fcore_FLX = find_reference "Gappa" ["Flocq"; "Core"; "FLX"]
+let coq_ref_Fcore_FLX = find_reference ["Flocq"; "Core"; "FLX"]
 let coq_FLX_format = coq_ref_Fcore_FLX "FLX_format"
 let coq_FLX_exp = coq_ref_Fcore_FLX "FLX_exp"
-let coq_ref_Fcore_FIX = find_reference "Gappa" ["Flocq"; "Core"; "FIX"]
+let coq_ref_Fcore_FIX = find_reference ["Flocq"; "Core"; "FIX"]
 let coq_FIX_format = coq_ref_Fcore_FIX "FIX_format"
 let coq_FIX_exp = coq_ref_Fcore_FIX "FIX_exp"
 
